const fetch = require('node-fetch');

/**
 * 获取放送时间、是否官方、是否收费
 * @param  {Number} seasonId 番剧 ID
 * @return {Object}          放送时间（ISO 8601 格式）、是否官方、是否收费
 */
function getInfo(seasonId) {
  const api = `http://bangumi.bilibili.com/jsonp/seasoninfo/${seasonId}.ver`;
  return fetch(api)
    .then(res => res.text())
    .then(text => (
      /^seasonListCallback/.test(text)
        ? text.match(/seasonListCallback\((.*)\);/)[1]
        : text
    ))
    .then(JSON.parse)
    .then(({ code, message, result }) => {
      if (code) {
        return Promise.reject(new Error(message));
      }
      return {
        begin: new Date(result.pub_time).toISOString() || '',
        official: result.copyright === 'bilibili' ||
          result.copyright === 'dujia' ||
          result.copyright === 'cooperate',
        premuiumOnly: !!(result.payment.price * 1),
      };
    });
}

module.exports = id =>
  getInfo(id)
    .then(info => Object.assign({ site: 'bilibili', id }, info))
    .catch(console.log);
